hesseflux.functions.logistic_function
=====================================

.. automodule:: hesseflux.functions.logistic_function
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

.. raw:: latex

    \clearpage
